package com.inteligr8.alfresco.activiti;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Component;

import com.inteligr8.alfresco.activiti.api.AppDefinitionsCxfApi;
import com.inteligr8.rs.AuthorizationFilter;
import com.inteligr8.rs.Client;
import com.inteligr8.rs.ClientConfiguration;

/**
 * This class provides the Apache CXF client to the JAX-RS API for the APS
 * Public ReST API.
 * 
 * @author brian@inteligr8.com
 */
@Component("aps.api.cxf")
@Lazy
public class ApsPublicRestApiCxfImpl extends ApsPublicRestApi {
	
	@Autowired
	private ApsClientCxfImpl client;
	
	/**
	 * This constructor is for Spring use
	 */
	protected ApsPublicRestApiCxfImpl() {
	}

	/**
	 * This constructor is for POJO use
	 */
	public ApsPublicRestApiCxfImpl(ApsClientCxfImpl client) {
		this.client = client;
	}
	
	@Override
	ClientConfiguration getConfig() {
		return this.client.getConfig();
	}
	
	@Override
	Client getClient() {
		return this.client;
	}
	
	public AppDefinitionsCxfApi getAppDefinitionsCxfApi() {
		return this.getApi(AppDefinitionsCxfApi.class);
	}
	
	public AppDefinitionsCxfApi getAppDefinitionsCxfApi(AuthorizationFilter authFilter) {
		return this.getApi(authFilter, AppDefinitionsCxfApi.class);
	}

}
